# Generated by roxygen2: do not edit by hand

export(adpcr2panel)
export(adpcr2ppp)
export(binarize)
export(bind_dpcr)
export(bioamp)
export(calc_coordinates)
export(compare_dens)
export(create_dpcr)
export(ddpcRquant)
export(df2dpcr)
export(dpcReport)
export(dpcr2df)
export(dpcr_density)
export(dpcr_density_gui)
export(dpcr_density_table)
export(extract_dpcr)
export(extract_run)
export(limit_cq)
export(moments)
export(num2int)
export(plot_panel)
export(plot_vic_fam)
export(qpcr2pp)
export(qpcr_analyser)
export(read_BioMark)
export(read_QX100)
export(read_QX200)
export(read_amp)
export(read_dpcr)
export(read_redf)
export(rename_dpcr)
export(sim_adpcr)
export(sim_dpcr)
export(test_counts)
export(test_counts_gui)
export(test_panel)
export(test_peaks)
export(test_pooled)
exportClasses(count_test)
exportMethods(coef)
exportMethods(plot)
exportMethods(show)
exportMethods(summary)
import(methods)
importFrom(binom,binom.confint)
importFrom(chipPCR,inder)
importFrom(dgof,cvm.test)
importFrom(dgof,ks.test)
importFrom(e1071,kurtosis)
importFrom(e1071,skewness)
importFrom(evd,fgev)
importFrom(evd,qgev)
importFrom(grDevices,adjustcolor)
importFrom(grDevices,col2rgb)
importFrom(grDevices,rainbow)
importFrom(grDevices,rgb)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,hist)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(graphics,symbols)
importFrom(graphics,text)
importFrom(multcomp,cld)
importFrom(multcomp,glht)
importFrom(multcomp,mcp)
importFrom(pracma,findpeaks)
importFrom(qpcR,eff)
importFrom(qpcR,efficiency)
importFrom(qpcR,modlist)
importFrom(qpcR,pcrfit)
importFrom(rateratio.test,rateratio.test)
importFrom(readxl,read_excel)
importFrom(shiny,runApp)
importFrom(signal,sgolayfilt)
importFrom(spatstat.geom,ppp)
importFrom(spatstat.explore,quadrat.test)
importFrom(stats,aggregate)
importFrom(stats,binomial)
importFrom(stats,dbinom)
importFrom(stats,dpois)
importFrom(stats,glm)
importFrom(stats,integrate)
importFrom(stats,mad)
importFrom(stats,median)
importFrom(stats,p.adjust)
importFrom(stats,pchisq)
importFrom(stats,predict)
importFrom(stats,prop.test)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,quasibinomial)
importFrom(stats,quasipoisson)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,smooth.spline)
importFrom(stats,symnum)
importFrom(stats,t.test)
importFrom(stats,var)
importFrom(stats,vcov)
importFrom(utils,combn)
importFrom(utils,getFromNamespace)
importFrom(utils,head)
importFrom(utils,read.csv)
importFrom(utils,read.table)
importFrom(utils,setTxtProgressBar)
importFrom(utils,tail)
importFrom(utils,txtProgressBar)
importFrom(utils,unzip)
