# Installation

dpcR is available [on CRAN](https://cran.r-project.org/package=dpcR), so installation is as simple as:

```R
install.packages("dpcR")
```

You can install the latest development version of the code using the `devtools` R package.

```R
# Install devtools, if you haven't already.
install.packages("devtools")

library(devtools)
install_github("michbur/dpcR")
```
