### About
  
**test_counts** uses generalized linear models (GLM) to perform multiple comparisions of digital PCR runs. It is a web-based implementation of function from package [dpcR](http://github.com/michbur/dpcR). 

**Authors**: [Michal Burdukiewicz](https://github.com/michbur), [Stefan Roediger](https://www.researchgate.net/profile/Stefan_Roediger).  

### Readme

1. *Number of molecules* - number of molecules in experiment.  
2. *Number of runs* - number of digital PCR reactions.  
