## Compare digital PCR experiments

Significance codes:  0 ‘\*\*\*’ 0.001 ‘\*\*’ 0.01 ‘\*’ 0.05 ‘.’ 0.1 ‘ ’ 1

For example, if a p-value has value between 0 and 0.001, it has significance code \*\*\*.
