### Moments of Poisson distribution

Table below represents four basic moments of Poisson distribution. Empirical moments are calculated using the sample data. Theoretical moments are computed using the estimated lambda value nad following relationships:  
  
* Mean: &lambda;
* Variance:  &lambda;
* Skewness  &lambda;^(0.5)
* Kurtosis:  &lambda;^(-1)
