### Explanation

1. Name of the run (NameOfExperiment.ReplicateID).
1. Name of the experiment.
1. ID of replicate.
1. Method used to compute statistics.
1. Mean number of template molecules per partition.
1. Lower border of the confidence interval for the mean number of template molecules per partition.
1. Upper border of the confidence interval for the mean number of template molecules per partition.
1. Number of template molecules.
1. Lower border of the confidence interval for the number of template molecules.
1. Upper border of the confidence interval for the number of template molecules.
1. Number of positive partitions.
1. Total number of partitions.
