There are several methods of calculating confidence intervals for binomial data (e.g., a status of partitions):
* Agresti-Coull.    
* Asymptotic.    
* Bayesian inference.    
* Cloglog parameterization.    
* Logit parameterization.    
* Pearson-Klopper.    
* Probit parameterization.    
* Proportion test.    
* Wilson.    

The Wilson confidence intervals are the most beneficial for dPCR experiment analysis, because they do not oscillate when the &lambda; is close to 0. For a deeper analysis, please refer to Brown, 2001 (full references list in the About panel).
