### Distribution of basic digital PCR parameters

The chart below describes the distribution of chosen dPCR parameter (k or &lambda;).

Parameters chosen below (confidence intervals level, method and so on) will be used in report.
