## Test array

A spatial randomness of positive partitions on the panel is tested using the quadrat test (see [quadrat.test](http://www.inside-r.org/packages/cran/spatstat/docs/quadrat.test) for description and references). You may specify the number of quadrats in X and Y direction using the context menu below.  

The results of analysis for each array may be exported by marking the "Visualise and analyze individually each array" checkbox in the "Download report"" section.
