## Welcome to dpcReport

For in-depth description of the dpcReport, please refer to the **About** panel.

### Upload data

Upload your data using the button below or analyze the preloaded data.

Accepted data formats:
* raw data - comma-separated .csv file (for array digital PCR and droplet digital PCR).
* QX100 - data from QX100 Droplet Digital PCR System (Life Technologies).
* BioMark (Detailed Table Results) - BioMark (Fluidigm).
* BioMark (Summary Table Results) - BioMark (Fluidigm).
* amplification data: compressed (.zip) directory with amplification data from QX series.

See also [exemplary data files](https://github.com/michbur/dpcR_data).

Accepted file formats:  
* .csv,  
* .xlsx,  
* .xls,
* .zip (only amplitude data).
