## Test array

The spatial analysis module is unavaible. You either do not supply array dPCR data or modified it through the GUI. The spatial analysis of panels is possible only for unmodified array dPCR data.
