The [box-and-whisker plot](http://docs.ggplot2.org/0.9.3.1/geom_boxplot.html) above describes the relationship between the experiment and the &lambda; value. Points belonging to the same experiment and with the same &lambda; value may be overplotted. In this case, consult the replicate/experiment scatterchart below.

### Scatter chart
