### The mean number of template molecules per partition

The table below contains the mean number of template molecules per partition (&lambda;) and its confidence intervals. The confidence intervals were adjusted to assure stable 0.95 simultaneous coverage probability, which offers more reliable comparison of technical repeats.

The automatically assigned group is represented by a single number (in case of the intermediate groups, a combination of numbers separated by dots). Groups contain experiments whose mean number of template molecules per partition are not significantly different.
