## Download report

Use menu below to choose elements of the report and download it using 'Download report' button.  

Each element of the report has an equivalent of a panel in the web server. Moreover, parameters set in the web server are carried to the report.   

### R code

Since dpcReport is written in [R language](https://cran.r-project.org/) using functions from **dpcR** package (see About panel), the analysis may be also conducted outside of the web server using the R environment. In this case check the box "R code used in the report generation". The report will contain ready to use code, which reproduces selected steps of the analysis performed in dpcReport. Any parameter adjusted by the user in the web server will be accordingly used in the code.

## Choose elements of the report  
